// SPDX-License-Identifier: GPL-3.0-or-later
// Copyright 2019 Juan Palacios <jpalaciosdev@gmail.com>

#pragma once

#include <string_view>

namespace AMD::MemFreq {

static constexpr std::string_view ItemID{"AMD_MEM_FREQ"};

} // namespace AMD::MemFreq
